@@ -1,11 +1,10 @@
 from flask_sqlalchemy import SQLAlchemy
-from postgresql_audit.flask import versioning_manager
 
 db = SQLAlchemy()
 
+
 Model = db.Model
 
-versioning_manager.init(Model)
 
 def get_model_with_table_name(table_name):
     for model in Model._decl_class_registry.values():
@@ -13,3 +12,9 @@ def get_model_with_table_name(table_name):
             continue
         if model.__tablename__ == table_name:
             return model
+
+
+def clean():
+    for table in reversed(db.metadata.sorted_tables):
+        db.session.execute(table.delete())
+    db.session.commit()
